/* Copyright (c) 2004, Jason Wolfe  <jawolfe@uclink.berkeley.edu>

   Permission is hereby granted, free of charge, to any person obtaining a copy of this software and 
   associated documentation files (the "Software"), to deal in the Software without restriction, including 
   without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
   copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the 
   following conditions:

   The above copyright notice and this permission notice shall be included in all copies or substantial 
   portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
   TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
   THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
   CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
   DEALINGS IN THE SOFTWARE.

   ( This is the BSD/MIT Open Source Licence,
     http://www.opensource.org/licenses/mit-license.php )
*/

/*  Residue.java
 *
 *  A simple class used to hold information about a single residue in the SCOP data set 
 *  The tmplReader class reads sequences of Residues, filling in all the information except for nContacts.
 *  nContacts is calculated later by the a DataClassifier.
 */


    public class Residue {
        public int aa;          // Residue identity (index in ProcessContacts.AAs)
        public int stype_8;     // 8-state Secondary structure (index in ProcessContacts.STypes_red8)
        public int stype_3;     // 3-state Secondary structure (index in ProcessContacts.STypes_red3)
                                   // (can be calculated from stype_8)
        
        public double x,y,z;    // Coordinates of beta-carbon in Angstroms
        public double burial;   // Surface exposure of residue
        int sLoc;               // 0-based index of residue in its sequence
        int sLen;               // Length of containing sequence ( # of residues )
        int nContacts=0;        // Number of contacts - filled in by DataClassifiers, not tmplReader
    };
